/*
Copyright 2021.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/pluralsh/plural-operator/api/platform/v1alpha1"
	scheme "github.com/pluralsh/plural-operator/generated/platform/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ProxiesGetter has a method to return a ProxyInterface.
// A group's client should implement this interface.
type ProxiesGetter interface {
	Proxies(namespace string) ProxyInterface
}

// ProxyInterface has methods to work with Proxy resources.
type ProxyInterface interface {
	Create(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.CreateOptions) (*v1alpha1.Proxy, error)
	Update(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.UpdateOptions) (*v1alpha1.Proxy, error)
	UpdateStatus(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.UpdateOptions) (*v1alpha1.Proxy, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Proxy, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.ProxyList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Proxy, err error)
	ProxyExpansion
}

// proxies implements ProxyInterface
type proxies struct {
	client rest.Interface
	ns     string
}

// newProxies returns a Proxies
func newProxies(c *PlatformV1alpha1Client, namespace string) *proxies {
	return &proxies{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the proxy, and returns the corresponding proxy object, and an error if there is any.
func (c *proxies) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.Proxy, err error) {
	result = &v1alpha1.Proxy{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("proxies").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Proxies that match those selectors.
func (c *proxies) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.ProxyList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ProxyList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("proxies").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested proxies.
func (c *proxies) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("proxies").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a proxy and creates it.  Returns the server's representation of the proxy, and an error, if there is any.
func (c *proxies) Create(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.CreateOptions) (result *v1alpha1.Proxy, err error) {
	result = &v1alpha1.Proxy{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("proxies").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(proxy).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a proxy and updates it. Returns the server's representation of the proxy, and an error, if there is any.
func (c *proxies) Update(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.UpdateOptions) (result *v1alpha1.Proxy, err error) {
	result = &v1alpha1.Proxy{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("proxies").
		Name(proxy.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(proxy).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *proxies) UpdateStatus(ctx context.Context, proxy *v1alpha1.Proxy, opts v1.UpdateOptions) (result *v1alpha1.Proxy, err error) {
	result = &v1alpha1.Proxy{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("proxies").
		Name(proxy.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(proxy).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the proxy and deletes it. Returns an error if one occurs.
func (c *proxies) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("proxies").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *proxies) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("proxies").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched proxy.
func (c *proxies) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Proxy, err error) {
	result = &v1alpha1.Proxy{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("proxies").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
